@@ -7,7 +7,7 @@ use File::Spec ();
 
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK};
 BEGIN {
-	$VERSION   = '1.12';
+	$VERSION   = '1.14';
 	@ISA       = 'Exporter';
 	@EXPORT    = 'which';
 	@EXPORT_OK = 'where';
@@ -210,17 +210,12 @@ Same as C<which($short_exe_name)> in array context. Same as the
 C<`where'> utility, will return an array containing all the path names
 matching C<$short_exe_name>.
 
-=head1 BUGS AND CAVEATS
+=head1 CAVEATS
 
 Not tested on VMS or MacOS, although there is platform specific code
 for those. Anyone who haves a second would be very kind to send me a
 report of how it went.
 
-File::Spec adds the current directory to the front of PATH if on
-Win32, VMS or MacOS. I have no knowledge of those so don't know if the
-current directory is searched first or not. Could someone please tell
-me?
-
 =head1 SUPPORT
 
 Bugs should be reported via the GitHub issue tracker
@@ -237,6 +232,13 @@ For other issues, contact the maintainer.
 
 Command line interface to this module.
 
+=iten L<IPC::Cmd>
+
+Comes with a C<can_run> function with slightly different semantics that
+the traditional UNIX where.  It will find executables in the current
+directory, even though the current directory is not searched for by
+default on Unix.
+
 =item L<Devel::CheckBin>
 
 This module purports to "check that a command is available", but does not
